import { Component, JSXElement, Show } from 'solid-js';
import {
  Dialog as MuiDialog,
  DialogContent,
  DialogTitle,
  IconButton,
} from '@suid/material';
import CloseIcon from '@suid/icons-material/Close';

const Dialog: Component<{
  open: boolean;
  fullScreen?: boolean;
  maxWidth?: boolean;
  title?: JSXElement;
  closeHandler: (event: any, reason?: string) => void;
  children: JSXElement;
}> = (props) => {
  return (
    <MuiDialog
      onClose={props.closeHandler}
      open={props.open}
      PaperProps={{ sx: { minWidth: '300px' } }}
      fullScreen={props.fullScreen}
    >
      <Show when={props.title}>
        <DialogTitle
          sx={{
            backgroundColor: 'rgba(14, 116, 144, 0.7)',
            color: 'white',
            clear: 'both',
            margin: '0',
            paddingLeft: '0',
          }}
        >
          <IconButton onClick={props.closeHandler}>
            <CloseIcon />
          </IconButton>
          {props.title}
        </DialogTitle>
      </Show>
      <DialogContent
        sx={{
          width: 'calc(100% - 60px)',
          paddingBottom:
            props.maxWidth === undefined || props.maxWidth ? '2000px' : '2px',
        }}
      >
        {props.children}
      </DialogContent>
    </MuiDialog>
  );
};

export default Dialog;
